sequencetools.join_subsequences_by_sign_of_elements
===================================================

.. autofunction:: abjad.tools.sequencetools.join_subsequences_by_sign_of_elements.join_subsequences_by_sign_of_elements
